@@ -22,6 +22,11 @@ babyphone - A baby monitor application on the Nokia N900.
 #include <QDebug>
 
 
+/*! 
+  The constructor initializes the scaling factors, sets up the threshold line
+  and sets up the associated QGraphicsView object. Furthermore, it stores the
+  reference to the application settings.
+*/
 AudioLevelGraphicsScene::AudioLevelGraphicsScene(QGraphicsView *graphicsView, Settings *settings, QObject *parent)
     : QGraphicsScene(parent), itsSettings(settings)
 {
@@ -41,36 +46,54 @@ AudioLevelGraphicsScene::AudioLevelGraphicsScene(QGraphicsView *graphicsView, Se
     setSceneRect(0, 0, itsWidth, -height);
     graphicsView->setSceneRect(0, 0, itsWidth, -height);
 
-    // setup middle line
-    addLine(0, GetYPos(itsSettings->THRESHOLD_VALUE), itsWidth,
-            GetYPos(itsSettings->THRESHOLD_VALUE), QPen(Qt::gray));
-
-    itsCurrentPosition = 0;
+    // initialize display
+    Clear();
 }
 
 
+/*!
+  AddValue takes the given audio data point and adds it to the graph.
+  If the graph reaches the end of the screen on its x-axes, the graph is cleared
+  to start over at the left again.
+*/
 void AudioLevelGraphicsScene::AddValue(float value)
 {
     // add current item
+	// values below the threshold are painted black, values above in red
     addLine(itsCurrentPosition, 0, itsCurrentPosition, GetYPos(value),
             value >= itsSettings->THRESHOLD_VALUE ? QPen(Qt::red) : QPen(Qt::black));
 
     // increment data pointer
     if (++itsCurrentPosition >= itsWidth) {
-        // reached end of screen
-        foreach(QGraphicsItem *item, items()) {
-            removeItem(item);
-            delete item;
-        }
-        // add middle line again
-        addLine(0, GetYPos(itsSettings->THRESHOLD_VALUE), itsWidth,
-                GetYPos(itsSettings->THRESHOLD_VALUE), QPen(Qt::gray));
-
-        itsCurrentPosition = 0;
+        // reached end of screen, clear display
+        Clear();
     }
 }
 
 
+/*!
+  Clear removes all objects from the graph and redraws the limit line.
+*/
+void AudioLevelGraphicsScene::Clear()
+{
+    // remove all items
+    foreach(QGraphicsItem *item, items()) {
+        removeItem(item);
+        delete item;
+    }
+
+    // add threshold line again
+    addLine(0, GetYPos(itsSettings->THRESHOLD_VALUE), itsWidth,
+            GetYPos(itsSettings->THRESHOLD_VALUE), QPen(Qt::gray));
+
+    // start again at the left
+    itsCurrentPosition = 0;
+}
+
+
+/*!
+  GetYPos derives the scaled y-value in pixels from the input value
+*/
 float AudioLevelGraphicsScene::GetYPos(float value)
 {
     return -(value-itsSettings->GRAPH_MIN_VALUE)*itsScale;
