@@ -19,6 +19,8 @@ babyphone - A baby monitor application on the Nokia N900.
 #include "ui_settings.h"
 
 #include <QDialog>
+#include <QDesktopServices>
+#include <QUrl>
 
 
 // settings keys and default values
@@ -38,6 +40,7 @@ babyphone - A baby monitor application on the Nokia N900.
 #define RECALL_TIMER_DEFAULT            180
 #define SWITCH_PROFILE_KEY              "application/switchProfile"
 #define SWITCH_PROFILE_DEFAULT          true
+#define FIRST_RUN_KEY                   "application/firstRun"
 #define SEND_SMS_KEY                    "application/sendSMS"
 #define SEND_SMS_DEFAULT                false
 #define REJECT_INCOMING_CALLS_KEY       "call/rejectIncoming"
@@ -45,6 +48,9 @@ babyphone - A baby monitor application on the Nokia N900.
 #define DISABLE_GRAPHS_KEY              "view/disableGraphsWhileMonitoring"
 #define DISABLE_GRAPHS_DEFAULT          false
 
+// further settings
+#define URL_HELP                        "http://babyphone.garage.maemo.org/index.html#sec_settings"
+
 
 /*!
   The constructor initializes the constant settings and loads the saved values
@@ -52,6 +58,7 @@ babyphone - A baby monitor application on the Nokia N900.
 */
 Settings::Settings(QObject *parent) :
     QSettings(COMPANY, PRODUCT, parent),
+    VERSION("0.2"),
     CALL_HOLD_TIMER(300000),    // 300s maximum call time
     THRESHOLD_VALUE(100),
     VOLUME_COUNTER_MAX(120),    // clipping occurs at this value
@@ -77,6 +84,7 @@ Settings::Settings(QObject *parent) :
     itsSendSMS = value(SEND_SMS_KEY, SEND_SMS_DEFAULT).toBool();
     itsHandleIncomingCalls = value(REJECT_INCOMING_CALLS_KEY, REJECT_INCOMING_CALLS_DEFAULT).toBool();
     itsDisableGraphs = value(DISABLE_GRAPHS_KEY, DISABLE_GRAPHS_DEFAULT).toBool();
+    itsFirstRun = value(FIRST_RUN_KEY, true).toBool();
 }
 
 
@@ -85,6 +93,7 @@ Settings::Settings(QObject *parent) :
 */
 void Settings::Save()
 {
+    setValue(FIRST_RUN_KEY, false);
     setValue(AUDIO_AMPLIFY_KEY, itsAudioAmplify);
     setValue(AUDIO_TIMER_KEY, itsAudioTimer);
     setValue(PHONE_NUMBER_KEY, itsPhonenumber);
@@ -106,7 +115,7 @@ void Settings::ShowDialog()
 {
     // setup settings dialog
     Ui::Dialog *ui = new Ui::Dialog();
-    QDialog *dialog = new QDialog();
+    QDialog *dialog = new QDialog(static_cast<QWidget*>(this->parent()));
     ui->setupUi(dialog);
     ui->spinBox_volume->setValue(itsAudioAmplify);
     ui->spinBox_timeWeight->setValue(itsAudioTimer);
@@ -117,8 +126,10 @@ void Settings::ShowDialog()
     ui->checkBox_sendSMS->setChecked(itsSendSMS);
     ui->checkBox_rejectIncomingCalls->setChecked(itsHandleIncomingCalls);
     ui->checkBox_disableGraphs->setChecked(itsDisableGraphs);
+    connect(ui->buttonBox, SIGNAL(helpRequested()), this, SLOT(ShowHelp()));
 
     // show dialog
+    dialog->setWindowModality(Qt::WindowModal);
     if (dialog->exec() == QDialog::Accepted)
     {
         // store new settings
@@ -138,3 +149,11 @@ void Settings::ShowDialog()
     delete dialog;
 }
 
+
+/*!
+  ShowHelp launches the online help.
+*/
+void Settings::ShowHelp()
+{
+    QDesktopServices::openUrl(QUrl(URL_HELP));
+}
